@@ -90,6 +90,7 @@ void DebugEvent(char *a,char *b,...)
 	h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
 	va_start(marker,b);
 	_vsnprintf(buf,MAXBUF_,b,marker);
+    buf[MAXBUF_] = '\0';
 	ptbuf[0] = buf;
 	ReportEvent(h, EVENTLOG_INFORMATION_TYPE, 0, 0, NULL, 1, 0, (const char **)ptbuf, NULL);\
 	DeregisterEventSource(h);
@@ -320,10 +321,10 @@ DWORD APIENTRY NPLogonNotify(
 	LPVOID StationHandle,
 	LPWSTR *lpLogonScript)
 {
-	char uname[256];
+	char uname[256]="";
 	char *ctemp;
-	char password[256];
-	char cell[256];
+	char password[256]="";
+	char cell[256]="<non-integrated logon>";
 	MSV1_0_INTERACTIVE_LOGON *IL;
 	DWORD code;
 	int pw_exp;
@@ -338,6 +339,9 @@ DWORD APIENTRY NPLogonNotify(
     int sleepInterval = DEFAULT_SLEEP_INTERVAL;        /* seconds        */
     BOOLEAN afsWillAutoStart;
 	CHAR RandomName[MAXRANDOMNAMELEN];
+    BOOLEAN uppercased_name = TRUE;
+
+    /* Initialize Logon Script to none */
 	*lpLogonScript=NULL;
         
 	IL = (MSV1_0_INTERACTIVE_LOGON *) lpAuthentInfo;
@@ -353,6 +357,14 @@ DWORD APIENTRY NPLogonNotify(
     ctemp = strchr(uname, '@');
     if (ctemp) *ctemp = 0;
 
+    /* is the name all uppercase? */
+    for ( ctemp = uname; *ctemp ; ctemp++) {
+        if ( islower(*ctemp) ) {
+            uppercased_name = FALSE;
+            break;
+        }
+    }
+
 	(void) RegOpenKeyEx(HKEY_LOCAL_MACHINE, REG_CLIENT_PARMS_KEY,
                         0, KEY_QUERY_VALUE, &NPKey);
 	LSPsize=sizeof(TraceOption);
@@ -374,63 +386,82 @@ DWORD APIENTRY NPLogonNotify(
 	RegCloseKey (NPKey);
 	if ((code!=0) || (LSPtype!=REG_DWORD))
 		LogonOption=LOGON_OPTION_INTEGRATED;	/*default to integrated logon only*/
-	DebugEvent("AFS AfsLogon - NPLogonNotify","LogonOption[%x], Service AutoStart[%d]",
-                LogonOption,AFSWillAutoStart());
-	/* Check for zero length password if integrated logon*/
-	if ( ISLOGONINTEGRATED(LogonOption) && (password[0] == 0) )  {
-		code = GT_PW_NULL;
-		reason = "zero length password is illegal";
-		code=0;
-	}
 
-	/* Get cell name if doing integrated logon */
-	if (ISLOGONINTEGRATED(LogonOption))
-	{
+	afsWillAutoStart = AFSWillAutoStart();
+        
+	DebugEvent("AFS AfsLogon - NPLogonNotify","LogonOption[%x], Service AutoStart[%d]",
+                LogonOption,afsWillAutoStart);
+    
+    /* Get local machine specified login behavior (or defaults) */
+    GetLoginBehavior(&retryInterval, &failSilently);
+        
+    /* Check for zero length password if integrated logon*/
+	if ( ISLOGONINTEGRATED(LogonOption) )  {
+        if ( password[0] == 0 ) {
+            code = GT_PW_NULL;
+            reason = "zero length password is illegal";
+            code=0;
+        }
+
+        /* Get cell name if doing integrated logon */
 		code = cm_GetRootCellName(cell);
 		if (code < 0) { 
 			code = KTC_NOCELL;
 			reason = "unknown cell";
 			code=0;
 		}
-	}
 
-    /* Get user specified login behavior (or defaults) */
-    GetLoginBehavior(&retryInterval, &failSilently);
-        
-    afsWillAutoStart = AFSWillAutoStart();
-        
-    /*only do if high security option is on*/
-    if (ISHIGHSECURITY(LogonOption))
-        *lpLogonScript = GetLogonScript(GenRandomName(RandomName));	
-    else
-        *lpLogonScript = GetLogonScript(uname);	
+        /*only do if high security option is on*/
+        if (ISHIGHSECURITY(LogonOption))
+            *lpLogonScript = GetLogonScript(GenRandomName(RandomName));	
+    }
 
     /* loop until AFS is started. */
     while (TRUE) {
         code=0;
 		
         /* is service started yet?*/
-
-        
         DebugEvent("AFS AfsLogon - ka_UserAuthenticateGeneral2","Code[%x] uname[%s] Cell[%s]",
                    code,uname,cell);
+
         /* if Integrated Logon only */
         if (ISLOGONINTEGRATED(LogonOption) && !ISHIGHSECURITY(LogonOption))
 		{			
-			code = ka_UserAuthenticateGeneral2(KA_USERAUTH_VERSION+KA_USERAUTH_AUTHENT_LOGON,
-                                                uname, "", cell, password,uname, 0, &pw_exp, 0,
+            if ( KFW_is_available() )
+                code = KFW_AFS_get_cred(uname, cell, password, 0, uname, &reason);
+            else
+                code = ka_UserAuthenticateGeneral2(KA_USERAUTH_VERSION+KA_USERAUTH_AUTHENT_LOGON,
+                                                uname, "", cell, password, uname, 0, &pw_exp, 0,
                                                 &reason);
 			DebugEvent("AFS AfsLogon - (INTEGRATED only)ka_UserAuthenticateGeneral2","Code[%x]",
                         code);
+            if ( code && code != KTC_NOCM && code != KTC_NOCMRPC && uppercased_name ) {
+                for ( ctemp = uname; *ctemp ; ctemp++) {
+                    *ctemp = tolower(*ctemp);
+                }
+                uppercased_name = FALSE;
+                continue;
+            }
 		} 
         /* if Integrated Logon and High Security pass random generated name*/
         else if (ISLOGONINTEGRATED(LogonOption) && ISHIGHSECURITY(LogonOption))
 		{
-			code = ka_UserAuthenticateGeneral2(KA_USERAUTH_VERSION+KA_USERAUTH_AUTHENT_LOGON,
+            if ( KFW_is_available() )
+                code = KFW_AFS_get_cred(uname, cell, password, 0, RandomName, &reason);
+            else
+                code = ka_UserAuthenticateGeneral2(KA_USERAUTH_VERSION+KA_USERAUTH_AUTHENT_LOGON,
                                                 uname, "", cell, password,RandomName, 0, &pw_exp, 0,
                                                 &reason);
 			DebugEvent("AFS AfsLogon - (Both)ka_UserAuthenticateGeneral2","Code[%x] RandomName[%s]",
                        code, RandomName);
+
+            if ( code && code != KTC_NOCM && code != KTC_NOCMRPC && uppercased_name ) {
+                for ( ctemp = uname; *ctemp ; ctemp++) {
+                    *ctemp = tolower(*ctemp);
+                }
+                uppercased_name = FALSE;
+                continue;
+            }
 		} else {  
             /*JUST check to see if its running*/
 		    if (IsServiceRunning())
@@ -474,6 +505,10 @@ DWORD APIENTRY NPLogonNotify(
         retryInterval -= sleepInterval;
     }
 
+    /* remove any kerberos 5 tickets currently held by the SYSTEM account */
+    if ( KFW_is_available() )
+        KFW_AFS_destroy_tickets_for_cell(cell);
+
 	if (code) {
         char msg[128];
         sprintf(msg, "Integrated login failed: %s", reason);
@@ -492,16 +527,18 @@ DWORD APIENTRY NPLogonNotify(
         }
 	    code = MapAuthError(code);
 		SetLastError(code);
-		if (ISHIGHSECURITY(LogonOption) && (code!=0))
+
+		if (ISLOGONINTEGRATED(LogonOption) && (code!=0))
 		{
 			if (*lpLogonScript)
 				LocalFree(*lpLogonScript);
 			*lpLogonScript = NULL;
-			if (!(afsWillAutoStart || ISLOGONINTEGRATED(LogonOption)))	// its not running, so if not autostart or integrated logon then just skip
-				return 0;
+			if (!afsWillAutoStart)	// its not running, so if not autostart or integrated logon then just skip
+				code = 0;
 
 		}
 	}
+
 	DebugEvent("AFS AfsLogon - Exit","Return Code[%x]",code);
 	return code;
 }
