@@ -401,6 +401,9 @@ long buf_AddBuffers(long nbuffers)
 	HANDLE hm;
 	long cs;
 
+    afsi_log("%d buffers being added to the existing cache of size %d",
+              nbuffers, buf_nbuffers);
+
 	/*
 	 * Cache file mapping constrained by
 	 * system allocation granularity;
@@ -1368,44 +1371,45 @@ long buf_CleanVnode(struct cm_scache *scp, cm_user_t *userp, cm_req_t *reqp)
 {
 	long code;
 	cm_buf_t *bp;		/* buffer we're hacking on */
-        cm_buf_t *nbp;		/* next one */
+    cm_buf_t *nbp;		/* next one */
 	long i;
 
 	i = BUF_FILEHASH(&scp->fid);
 
 	code = 0;
 	lock_ObtainWrite(&buf_globalLock);
-        bp = buf_fileHashTablepp[i];
-        if (bp) bp->refCount++;
-        lock_ReleaseWrite(&buf_globalLock);
+    bp = buf_fileHashTablepp[i];
+    if (bp) bp->refCount++;
+    lock_ReleaseWrite(&buf_globalLock);
 	for(; bp; bp = nbp) {
 		/* clean buffer synchronously */
 		if (cm_FidCmp(&bp->fid, &scp->fid) == 0) {
 			if (userp) {
+                cm_HoldUser(userp);
 				lock_ObtainMutex(&bp->mx);
-				if (bp->userp) cm_ReleaseUser(bp->userp);
-                                bp->userp = userp;
+				if (bp->userp) 
+                    cm_ReleaseUser(bp->userp);
+                bp->userp = userp;
 				lock_ReleaseMutex(&bp->mx);
-                                cm_HoldUser(userp);
-                        }
+            }
 			buf_CleanAsync(bp, reqp);
-	                buf_CleanWait(bp);
-                        lock_ObtainMutex(&bp->mx);
+            buf_CleanWait(bp);
+            lock_ObtainMutex(&bp->mx);
 			if (bp->flags & CM_BUF_ERROR) {
 				if (code == 0 || code == -1) code = bp->error;
-                                if (code == 0) code = -1;
-                        }
-                        lock_ReleaseMutex(&bp->mx);
+                if (code == 0) code = -1;
+            }
+            lock_ReleaseMutex(&bp->mx);
 		}
 
 		lock_ObtainWrite(&buf_globalLock);
 		buf_LockedRelease(bp);
-                nbp = bp->fileHashp;
-                if (nbp) nbp->refCount++;
+        nbp = bp->fileHashp;
+        if (nbp) nbp->refCount++;
 		lock_ReleaseWrite(&buf_globalLock);
 	}	/* for loop over a bunch of buffers */
 	
-        /* done */
+    /* done */
 	return code;
 }
 
@@ -1417,6 +1421,9 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie)
     char output[1024];
     int i;
   
+	if (buf_hashTablepp == NULL)
+		return -1;
+
     lock_ObtainRead(&buf_globalLock);
   
     sprintf(output, "%s - dumping buf_HashTable - buf_hashSize=%d\n", cookie, buf_hashSize);
