@@ -155,6 +155,9 @@ void DrivesTab_OnCheck (HWND hDlg)
             Message (MB_OK | MB_ICONHAND, IDS_ERROR_UNMAP, IDS_ERROR_UNMAP_DESC, TEXT("%08lX"), dwStatus);
          DrivesTab_FillList (hDlg);
          }
+      WriteActiveMap(g.Configuration.NetDrives.aDriveMap[ iDriveSel ].chDrive, fChecked && 
+                     g.Configuration.NetDrives.aDriveMap[ iDriveSel ].fPersistent );
+
       }
 }
 
@@ -199,6 +202,7 @@ void DrivesTab_OnRemove (HWND hDlg)
 
          DrivesTab_FillList (hDlg);
          }
+      WriteActiveMap(g.Configuration.NetDrives.aDriveMap[ iDriveSel ].chDrive, FALSE );
       }
 }
 
@@ -351,6 +355,13 @@ void DrivesTab_EditMapping (HWND hDlg, int iDrive)
          lstrcpy (g.Configuration.NetDrives.aDriveMap[ DriveMap.chDrive-chDRIVE_A ].szMapping, szAfsPathNew);
          WriteDriveMappings (&g.Configuration.NetDrives);
 
+         if (iDrive == -1) {
+             WriteActiveMap(DriveMap.chDrive, DriveMap.fPersistent);
+         } else if ( (chDRIVE_A + iDrive) != DriveMap.chDrive ) {
+             WriteActiveMap(chDRIVE_A+iDrive, FALSE);
+             WriteActiveMap(DriveMap.chDrive, DriveMap.fPersistent);
+         }
+
          DrivesTab_FillList (hDlg);
          }
       }
@@ -433,10 +444,8 @@ void DriveEdit_OnInitDialog (HWND hDlg)
    SendMessage (hCombo, CB_SETCURSEL, iItemSel, 0);
 
    TCHAR szMapping[ MAX_PATH ];
-   memset(szMapping, '\0', sizeof(szMapping));
-   szMapping[0] = '\\';
-   lana_GetNetbiosName(&szMapping[1], LANA_NETBIOS_NAME_FULL);
-
+   AdjustAfsPath (szMapping, ((pMap->szMapping[0]) ? pMap->szMapping : cm_slash_mount_root), TRUE, FALSE);
+   
    CHAR msg[256], msgf[256];
    if (GetDlgItemText(hDlg,IDC_STATICSUBMOUNT,(LPSTR)msg,sizeof(msg)-1)>0)
    {
