@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.42 2004/03/19 07:58:52 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.44 2004/04/21 02:20:21 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -74,7 +74,9 @@ osi_Init(void)
 #endif /* AFS_HPUX_ENV */
 
     if (!afs_osicred_initialized) {
-#ifdef AFS_XBSD_ENV
+#if defined(AFS_LINUX26_ENV)
+	afs_osi_credp = crref();
+#elif defined(AFS_XBSD_ENV)
 	/* Can't just invent one, must use crget() because of mutex */
 	afs_osi_credp = crdup(osi_curcred());
 #else
@@ -1058,8 +1060,13 @@ afs_osi_proc2cred(AFS_PROC * pr)
 	|| (pr->state == TASK_STOPPED)) {
 	cr.cr_ref = 1;
 	cr.cr_uid = pr->uid;
+#if defined(AFS_LINUX26_ENV)
+	get_group_info(pr->group_info);
+	cr.cr_group_info = pr->group_info;
+#else
 	cr.cr_ngroups = pr->ngroups;
 	memcpy(cr.cr_groups, pr->groups, NGROUPS * sizeof(gid_t));
+#endif
 	rv = &cr;
     }
 
